@@ -21,6 +21,116 @@ package inc::MBX::Alien::FLTK::Platform::Unix;
                     \$x
                 }
         );
+
+        # Asssumed true since this is *nix
+        $self->notes('define')->{'USE_X11'} = !grep {m[^no_x11$]} @args;
+        print "have pthread... yes (assumed)\n";
+        $self->notes('define')->{'HAVE_PTHREAD'} = 1;
+        $self->notes('ldflags' => $self->notes('ldflags') . ' -lpthread ');
+        print "have sys/ndir.h... \n";
+        $self->notes('define')->{'HAVE_SYS_NDIR_H'}
+            = ($self->find_h('sys/ndir.h') ? 1 : undef);
+        print "have sys/dir.h... \n";
+        $self->notes('define')->{'HAVE_SYS_DIR_H'}
+            = ($self->find_h('sys/dir.h') ? 1 : undef);
+        print "have ndir.h... \n";
+        $self->notes('define')->{'HAVE_NDIR_H'}
+            = ($self->find_h('ndir.h') ? 1 : undef);
+        {
+            print
+                'Checking whether we have the POSIX compatible scandir() prototype... ';
+            my $obj = $self->compile({code => <<'' });
+#include <dirent.h>
+int func (const char *d, dirent ***list, void *sort) {
+    int n = scandir(d, list, 0, (int(*)(const dirent **, const dirent **))sort);
+}
+int main ( ) {
+    return 0;
+}
+
+            if ($obj ? 1 : 0) {
+                print "yes\n";
+                $self->notes('define')->{'HAVE_SCANDIR_POSIX'} = 1;
+            }
+            else {
+                print "no\n";
+                $self->notes('define')->{'HAVE_SCANDIR_POSIX'} = undef;
+            }
+        }
+        {
+            print "Checking string functions...\n";
+            if (($self->notes('os') =~ m[^hpux$]i)
+                && $self->notes('os_ver') == 1020)
+            {   print
+                    "\nNot using built-in snprintf function because you are running HP-UX 10.20\n";
+                $self->notes('define')->{'HAVE_SNPRINTF'} = undef;
+                print
+                    "\nNot using built-in vnprintf function because you are running HP-UX 10.20\n";
+                $self->notes('define')->{'HAVE_VNPRINTF'} = undef;
+            }
+            elsif (($self->notes('os') =~ m[^dec_osf$]i)
+                   && $self->notes('os_ver') == 40)
+            {   print
+                    "\nNot using built-in snprintf function because you are running Tru64 4.0.\n";
+                $self->notes('define')->{'HAVE_SNPRINTF'} = undef;
+                print
+                    "\nNot using built-in vnprintf function because you are running Tru64 4.0.\n";
+                $self->notes('define')->{'HAVE_VNPRINTF'} = undef;
+            }
+        }
+        {
+            my %functions = (
+                strdup      => 'HAVE_STRDUP',
+                strcasecmp  => 'HAVE_STRCASECMP',
+                strncasecmp => 'HAVE_STRNCASECMP',
+                strlcat     => 'HAVE_STRLCRT',
+
+                #strlcpy     => 'HAVE_STRLCPY'
+            );
+            for my $func (keys %functions) {
+                printf 'Checking for %s... ', $func;
+                my $obj = $self->compile({code => <<""});
+/* Define $func to an innocuous variant, in case <limits.h> declares $func.
+   For example, HP-UX 11i <limits.h> declares gettimeofday.  */
+#define $func innocuous_$func
+/* System header to define __stub macros and hopefully few prototypes,
+    which can conflict with char $func (); below.
+    Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
+    <limits.h> exists even on freestanding compilers.  */
+#ifdef __STDC__
+# include <limits.h>
+#else
+# include <assert.h>
+#endif
+#undef $func
+/* Override any GCC internal prototype to avoid an error.
+   Use char because int might match the return type of a GCC
+   builtin and then its argument prototype would still apply.  */
+#ifdef __cplusplus
+extern "C"
+#endif
+char $func ();
+/* The GNU C library defines this for functions which it implements
+    to always fail with ENOSYS.  Some functions are actually named
+    something starting with __ and the normal name is an alias.  */
+#if defined __stub_$func || defined __stub___$func
+choke me
+#endif
+int main () {
+    return $func ();
+    return 0;
+}
+
+                if ($obj) {
+                    print "yes\n";
+                    $self->notes('define')->{$functions{$func}} = 1;
+                }
+                else {
+                    print "no\n";
+                    $self->notes('define')->{$functions{$func}} = undef;
+                }
+            }
+        }
         {
 
             # Use the X overlay extension for MenuWindow and Tooltips. Pretty
